==> bonita-server-8.0.0-sources.jar: org/bonitasoft/engine/synchro/AbstractJMSUpdateHandler.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.synchro;

import java.io.Serializable;
import java.util.Map;

import org.bonitasoft.engine.service.TenantServiceAccessor;
import org.bonitasoft.engine.transaction.BonitaTransactionSynchronization;

/**
 * @author Baptiste Mesta
 * @author Guillaume Rosinosky
 */
public abstract class AbstractJMSUpdateHandler extends AbstractUpdateHandler {

    private static final long serialVersionUID = 1L;

    private final Long messageTimeout;

    private String brokerURL;

    public AbstractJMSUpdateHandler(final long messageTimeout, String brokerURL) {
        super();
        this.messageTimeout = messageTimeout;
        this.brokerURL = brokerURL;
    }

    @Override
    protected BonitaTransactionSynchronization getSynchronization(final Map<String, Serializable> event, final Long id,
            final TenantServiceAccessor tenantServiceAccessor) {
        return new SendJMSMessageSynchronization(event, id, JMSProducer.getInstance(messageTimeout, brokerURL));
    }
}

==> bonita-server-10.0.0-sources.jar: org/bonitasoft/engine/synchro/AbstractJMSUpdateHandler.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.synchro;

import java.io.Serializable;
import java.util.Map;

import org.bonitasoft.engine.service.ServiceAccessor;
import org.bonitasoft.engine.transaction.BonitaTransactionSynchronization;

/**
 * @author Baptiste Mesta
 * @author Guillaume Rosinosky
 */
public abstract class AbstractJMSUpdateHandler extends AbstractUpdateHandler {

    private static final long serialVersionUID = 1L;

    private final Long messageTimeout;

    private String brokerURL;

    public AbstractJMSUpdateHandler(final long messageTimeout, String brokerURL) {
        super();
        this.messageTimeout = messageTimeout;
        this.brokerURL = brokerURL;
    }

    @Override
    protected BonitaTransactionSynchronization getSynchronization(final Map<String, Serializable> event, final Long id,
            final ServiceAccessor serviceAccessor) {
        return new SendJMSMessageSynchronization(event, id, JMSProducer.getInstance(messageTimeout, brokerURL));
    }
}
